import { Plugin, Transaction } from 'prosemirror-state';
import { Command as ProseMirrorCommand } from 'prosemirror-commands';
import { InputRule } from 'prosemirror-inputrules';
import { Editor } from './Editor';
import { Node } from './Node';
import { GlobalAttributes, RawCommands, ExtensionConfig } from './types';
declare module '@tiptap/core' {
    interface ExtensionConfig<Options = any> {
        [key: string]: any;
        /**
         * Name
         */
        name: string;
        /**
         * Default options
         */
        defaultOptions?: Options;
        /**
         * Global attributes
         */
        addGlobalAttributes?: (this: {
            options: Options;
        }) => GlobalAttributes | {};
        /**
         * Raw
         */
        addCommands?: (this: {
            options: Options;
            editor: Editor;
        }) => Partial<RawCommands>;
        /**
         * Keyboard shortcuts
         */
        addKeyboardShortcuts?: (this: {
            options: Options;
            editor: Editor;
        }) => {
            [key: string]: ProseMirrorCommand;
        };
        /**
         * Input rules
         */
        addInputRules?: (this: {
            options: Options;
            editor: Editor;
        }) => InputRule[];
        /**
         * Paste rules
         */
        addPasteRules?: (this: {
            options: Options;
            editor: Editor;
        }) => Plugin[];
        /**
         * ProseMirror plugins
         */
        addProseMirrorPlugins?: (this: {
            options: Options;
            editor: Editor;
        }) => Plugin[];
        /**
         * Extend Node Schema
         */
        extendNodeSchema?: ((this: {
            options: Options;
        }, extension: Node) => {
            [key: string]: any;
        }) | null;
        /**
         * Extend Mark Schema
         */
        extendMarkSchema?: ((this: {
            options: Options;
        }, extension: Node) => {
            [key: string]: any;
        }) | null;
        /**
         * The editor is ready.
         */
        onCreate?: ((this: {
            options: Options;
            editor: Editor;
        }) => void) | null;
        /**
         * The content has changed.
         */
        onUpdate?: ((this: {
            options: Options;
            editor: Editor;
        }) => void) | null;
        /**
         * The selection has changed.
         */
        onSelectionUpdate?: ((this: {
            options: Options;
            editor: Editor;
        }) => void) | null;
        /**
         * The view has changed.
         */
        onViewUpdate?: ((this: {
            options: Options;
            editor: Editor;
        }) => void) | null;
        /**
         * The editor state has changed.
         */
        onTransaction?: ((this: {
            options: Options;
            editor: Editor;
        }, props: {
            transaction: Transaction;
        }) => void) | null;
        /**
         * The editor is focused.
         */
        onFocus?: ((this: {
            options: Options;
            editor: Editor;
        }, props: {
            event: FocusEvent;
        }) => void) | null;
        /**
         * The editor isn’t focused anymore.
         */
        onBlur?: ((this: {
            options: Options;
            editor: Editor;
        }, props: {
            event: FocusEvent;
        }) => void) | null;
        /**
         * The editor is destroyed.
         */
        onDestroy?: ((this: {
            options: Options;
            editor: Editor;
        }) => void) | null;
    }
}
export declare class Extension<Options = any> {
    #private;
    type: string;
    config: ExtensionConfig;
    options: Options;
    constructor(config: ExtensionConfig<Options>);
    static create<O>(config: ExtensionConfig<O>): Extension<O>;
    configure(options?: Partial<Options>): Extension<Options>;
    extend<ExtendedOptions = Options>(extendedConfig: Partial<ExtensionConfig<ExtendedOptions>>): Extension<ExtendedOptions>;
}
